
# Slot: is_a




URI: [linkml:permissible_value_is_a](https://w3id.org/linkml/permissible_value_is_a)


## Domain and Range

[PermissibleValue](PermissibleValue.md) &#8594;  <sub>0..1</sub> [PermissibleValue](PermissibleValue.md)

## Parents

 *  is_a: [is_a](is_a.md)

## Children


## Used by

 * [PermissibleValue](PermissibleValue.md)
